@@ -83,31 +83,21 @@ rtf_encode_figure <- function(tbl) {
     if (!is.null(subline_rtftext)) subline_rtftext <- c(rep("", n_page - 1), subline_rtftext)
   }
 
-  # Footnote Display Location
-  if (page$page_footnote == "first") {
-    footnote_rtftext <- c(footnote_rtftext, rep("", n_page - 1))
-  }
+  # Title RTF encoding by page
 
-  if (page$page_footnote == "last") {
-    footnote_rtftext <- c(rep("", n_page - 1), footnote_rtftext)
-  }
+  # Footnote RTF encoding by page
+  footnote_rtftext <- switch(page$page_footnote,
+    first = c(footnote_rtftext, rep("", n_page - 1)),
+    last  = c(rep("", n_page - 1), footnote_rtftext),
+    all   = rep(footnote_rtftext, n_page)
+  )
 
-  if (page$page_footnote == "all") {
-    footnote_rtftext <- c(rep(footnote_rtftext, n_page - 1), footnote_rtftext)
-  }
-
-  # Page Source Display Location
-  if (page$page_source == "first") {
-    source_rtftext <- c(source_rtftext, rep("", n_page - 1))
-  }
-
-  if (page$page_source == "last") {
-    source_rtftext <- c(rep("", n_page - 1), source_rtftext)
-  }
-
-  if (page$page_source == "all") {
-    source_rtftext <- c(rep(source_rtftext, n_page - 1), source_rtftext)
-  }
+  # Source RTF encoding by page
+  source_rtftext <- switch(page$page_source,
+    first = c(source_rtftext, rep("", n_page - 1)),
+    last  = c(rep("", n_page - 1), source_rtftext),
+    all   = rep(source_rtftext, n_page)
+  )
 
   rtf_feature <- paste(
     page_rtftext,
